==> Glossary-0.6.7.tar.gz: Glossary/lang/ext/nl_NL.php <==
<?php
$lang['areyousure_altercontent'] = 'Weet je zeker dat je door wil gaan? Doorgaan verandert de inhoud voorgoed';
$lang['filter_site_now'] = 'Filter nu';
$lang['friendlyname'] = 'Woordenlijst / Woordenboek';
$lang['postinstall'] = '<p>Vergewis u ervan de &quot;Modify Glossary&quot; rechten voor deze module in te stellen!</p>
<p>Waarschijnlijk wilt u de instellingen ook wijzigen. Er zijn opzettelijk vreemde standaardinstellingen gekozen om bepaalde mogelijkheden te tonen. Maar waarschijnlijk wilt u meer dan vijf termen per pagina, om een voorbeeld te noemen, en wilt u de voorbeeldtermen en -categorie&euml;n verwijderen.';
$lang['postuninstall'] = 'Verwijderd.';
$lang['uninstalled'] = 'Module gede&iuml;nstalleerd';
$lang['installed'] = 'Module versie %s ge&iuml;nstalleerd.';
$lang['prefsupdated'] = 'Modulevoorkeuren bijgewerkt.';
$lang['accessdenied'] = 'Toegang geweigerd. Controleer de rechten.';
$lang['error'] = 'Fout!';
$lang['upgraded'] = 'Module bijgewerkt naar versie %s.';
$lang['title_mod_prefs'] = 'Modulevoorkeuren';
$lang['title_mod_admin'] = 'Modulebeheerpagina';
$lang['title_term'] = 'Term ';
$lang['title_definition'] = 'Definitie';
$lang['column_definition'] = 'Definitie';
$lang['title_default_template'] = 'Standaard weergavesjabloon';
$lang['title_default_single_term_template'] = 'Standaard sjabloon voor gekoppelde termen (als een enkele term wordt getoond)';
$lang['title_filter_site'] = 'Filter website op termen?';
$lang['title_filter_news'] = 'Filter News artikels voor termen?';
$lang['title_number_show'] = 'Aantal weer te geven termen per pagina';
$lang['title_default_number_show'] = 'Standaard aantal termen die worden getoond op de pagina';
$lang['title_filter_site_label'] = 'Activeer alle termen op de website? (waarschuwing - vertraagt de website)';
$lang['title_glossary_page'] = 'Woordenlijstpagina (target voor actieve links)';
$lang['title_disable_prettyurls'] = 'Schakel &quot;pretty urls&quot; uit voor deze module';
$lang['title_disable_prettyurls_label'] = 'Uitschakelen';
$lang['title_glossary_inline'] = 'Inline gekoppelde termweergave?';
$lang['title_show_termids'] = 'Toon Term ID nummers in administratie';
$lang['title_display_tab'] = 'Woordenlijst paginaweergaveopties';
$lang['title_single_term'] = 'Toon gekoppelde term op zijn eigen pagina?';
$lang['title_single_term_label'] = 'Toon enkele term (in tegenstelling tot volledige woordenlijst)';
$lang['title_wysiwyg_definitions'] = 'Gebruik WYSIWYG voor het invoeren van term definities?';
$lang['title_wysiwyg_terms'] = 'Gebruik WYSIWYG voor het invoeren van termen?';
$lang['title_wysiwyg_terms_help'] = 'Please note that markup inside terms can interfere with alphabetizing and with activated terms!';
$lang['title_link_tab'] = 'Woordenlijst koppelingsopties';
$lang['title_admin_tab'] = 'Beheerpaginaopties';
$lang['title_filtering_tab'] = 'Website term-filteringsopties';
$lang['title_number_spining_chars'] = 'Max aantal karakters in een term in de Woordenlijstnavigatie';
$lang['title_process_smarty'] = 'Gebruik Smarty tags in de definities?';
$lang['filter_link'] = 'Link naar Woordenlijstpagina';
$lang['column_term'] = 'Term ';
$lang['column_termid'] = 'Term-id';
$lang['column_action'] = 'Actie';
$lang['column_category'] = 'Categorie';
$lang['title_admin_panel'] = 'Woordelijk / Woordenboek / FAQ';
$lang['title_term_list'] = 'Termen';
$lang['title_name'] = 'Naam';
$lang['title_cats'] = 'Categorie&euml;n';
$lang['title_filter_category'] = 'Toon alleen categorie:';
$lang['title_all'] = 'Alle categorie&euml;n';
$lang['column_template'] = 'Sjabloonnaam';
$lang['title_template'] = 'Sjabloondefinitie';
$lang['addterm'] = 'Voeg nieuwe term toe';
$lang['termadded'] = 'Term is toegevoegd.';
$lang['termdeleted'] = 'Term is verwijderd.';
$lang['edit'] = 'Bewerk term';
$lang['no'] = 'Nee';
$lang['yes'] = 'Ja';
$lang['filter'] = 'Filter ';
$lang['delete'] = 'Verwijder term';
$lang['suredelete'] = 'Weet u zeker dat u term %s wilt verwijderen?';
$lang['listterms'] = 'Beheer termen';
$lang['listtempl'] = 'Beheer sjablonen';
$lang['listcats'] = 'Beheer categorie&euml;n';
$lang['addcat'] = 'Voeg categorie toe';
$lang['editcat'] = 'Bewerk categorie';
$lang['delcat'] = 'Verwijder categorie';
$lang['manageprefs'] = 'Beheervoorkeuren';
$lang['templatelist'] = 'Sjablonen';
$lang['unknown_term'] = 'Onbekende term %s is opgevraagd.';
$lang['glossary_page_help'] = 'Selecteer een onderstaande pagina die de tag bevat om de woordenlijstinformatie te tonen, b.v. een pagina met {cms_module module=&quot;Glossary&quot;}';
$lang['glossary_prettyurls_help'] = 'Uitschakelen van de &quot;pretty urls&quot; voor deze module kan helpen als niet-alfanumerieke waardes, of blancos worden gebruikt.';
$lang['glossary_inline_help'] = 'Gebruik de volgende optie als u uw actieve-termdefinities in-line wilt weergeven. Dit is wederzijds uitsluitend met een koppeling naar een Woordenlijstpagina';
$lang['title_glossary_inline_label'] = 'Toon inline';
$lang['notemplates'] = 'Geen sjablonen in de database.';
$lang['nocats'] = 'Geen categorie&euml;n in de database.';
$lang['addtemplate'] = 'Voeg een sjabloon toe';
$lang['templateupdated'] = 'Sjabloon bijgewerkt';
$lang['templatedeleted'] = 'Sjabloon verwijderd';
$lang['catupdated'] = 'Categorie bijgewerkt';
$lang['catdeleted'] = 'Categorie verwijderd';
$lang['areyousure'] = 'Weet u zeker dat %s verwijderd moet worden?';
$lang['next'] = ' : Volgende &raquo;';
$lang['prev'] = '&laquo; Vorige : ';
$lang['moddescription'] = 'Met deze module maakt u lijsten met termen en definities om weer te geven. Een term kan  een woord, een veelgestelde vraag of iets vergelijkbaars zijn.';
$lang['changelog'] = '<ul>
<li>Version 0.6.6,  January 2009. Bug fixes, code refactoring, added &quot;random&quot; action, option to allow smarty tags in definitions, options for WYSIWYG.</li>
<li>Version 0.6.5,  January 2009. Bug fixes, now allows teplate specification to be name or id.</li>
<li>Version 0.6.4,  September 2008.  Adds glossary terms to the searchable content.  Bump minimum cms version to 1.4.1</li>
<li>Version 0.6.3,  March 2008.  Adds the ability to disable pretty urls for this module.  Bump minimum cms version to 1.2</li>
<li>Version 0.6.2.  December 2007.  Fixes a bug in preferences related to inline/non inline, bumps minimum cms version, Adds the RegisterModulePlugin call.</li>
<li>Version 0.6.1.  November 2007.  Adds functionality so that content never returns empty</li>
<li>Version 0.6. November 2007.  Adds a button to filter content and news on demand, splits it out into multiple files for reduced memory footprint.</li>
<li>Version 0.5.1. 28 Mar 2007.  Urls now validate. There ya go, Mr. InSiPiD.</li>
<li>Version 0.5. 8 November 2006. Removed pop-up window links, added inline display, and category filtering / requested features for InSiPiD.</li>
<li>Version 0.4. 7 November 2006. Updated for CMS MS 1.0.x, added features for InSiPiD.</li>
<li>Version 0.3. 24 October 2005. Bug fixes, new default template, more Admin configuration options.</li>
<li>Version 0.2. 20 October 2005. Initial Public Release.</li></ul>';
$lang['help_glossary_single'] = 'Laat &eacute;&eacute;n term zien';
$lang['help_glossary_tid'] = 'Term ID om op te lichten';
$lang['help_glossary_catid'] = 'Restrict list to terms in category ID &quot;catid&quot;';
$lang['help_glossary_start'] = 'Offset in list to start listing terms';
$lang['help_glossary_term'] = 'Woord om op te lichten';
$lang['help_glossary_cat'] = 'Restrict list to terms in category &quot;cat&quot;';
$lang['help_glossary_template'] = 'Sjabloon naam of ID om te gebruiken bij Termen';
$lang['help_glossary_term_count'] = 'Aantal termen om te laten zien op een pagina (overschrijft standaard instellingen van de admin)';
$lang['help_glossary_show_nav'] = 'Stel in op 0 om de pagina navigatie te verstoppen';
$lang['help_glossary_keyword'] = 'Restrict to terms whose definitions contain &quot;keyword&quot;';
$lang['help_glossary_sort'] = 'Sort order: currently only supports &quot;alpha&quot; or &quot;random&quot;';
$lang['help_glossary_no_pass_restrictions'] = 'To display a filtered or otherwise restricted list, but to have the expanded list not restricted, list the fields here (see example above)';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This allows the administrator to create a list of terms, which will appear on a page. Clicking on the term will expand it to include the definition.</p>
<h3>How Do I Use It</h3>
<h4>Standard Glossary Page</h4>
<p>Install it by placing the module in a page or template using the smarty tag &amp;#123;cms_module module=&#039;Glossary&#039;}</p>
<p>You can have it start with a term expanded by passing a term=Term parameter, or passing a tid=term_id.</p>
<p>You can limit it to a specific category by passing a cat=&quot;Category&quot; parameter.</p>
<p>You can override the default template by passing a template=&quot;template_id&quot; parameter (use the numeric
id for the template, or the template name).</p>
<p>You can limit it to definitions containing a keyword by passing a keyword=&quot;keyword&quot;.</p>
<p>This module also will read the URL, and support specifications of &quot;term&quot; or &quot;cat&quot; on the URL. So, for example, you could have an URL like http://mysite/index.php?page=10&amp;amp;term=myterm. If page 10 includes the Glossary module, it will expand the definition of &quot;myterm&quot;.
<h4>Expanding Lists</h4>
<p>Sometimes, you will want a short list of terms, but have clicks on those terms to load a full list. For example, you might want three random terms in the sidebar, but clicking on those terms should show the selected term in a complete term list. To do this, set the &quot;no_pass_restriction&quot; variable.</p>
<p>For example, on your sidebar you want three random terms from category &quot;foo&quot;. Clicking on a term should show a full, alphabetical list of category &quot;foo&quot; with the specific term open. Your tag for the sidebar will then look like:</p>
<p>&amp;#123;cms_module module=&#039;Glossary&#039; cat=&#039;foo&#039; sort=&#039;random&#039; term_count=&#039;3&#039; no_pass_restriction=&#039;sort,term_count&#039;}</p>
<h4>WYSIWYG/Smarty</h4>
<p>In the admin, you can enable the WYSIWYG editor for terms and term definitions. Because of the way the system uses terms, it is not recommended
to use markup in the terms themselves. If you insist on doing it (and some people do, in fact, have good reasons to do so), be aware that site filtering will probably break, and the glossary page nav may be messed up.</p>
<p>You can also enable smarty processing on term definitions. This will permit you to do all sorts of wild stuff like self-linking and other smarty madness. Hey -- if you know enough to go on the black diamond run, you know the risks! I will say no more.</p>
<h3>Linked Terms</h3>
<h4>Overview</h4>
<p>You can make terms that show up in your pages link to their definitions, either &quot;inline&quot; (where it replaces the content of your page), or by linking to your main Glossary page. This is the &quot;inline&quot; option which you can set in the &quot;Glossary Links Options&quot; section of the Glossary Admin Prefs.</p>
<p>You can also choose to have links go to a page with only the definition of your term, and you can control the display of this by altering the template. This also set in &quot;Glossary Links Options&quot; section of the Glossary Admin Prefs.</p> 
<h4>Single Term</h4>
<p>You can tag specific words to be linked to the Glossary if you want, by placing the following tag in a page: &amp;#123;cms_module module=&#039;Glossary&#039; action=&#039;def&#039; term=&#039;foo&#039;}, where you replace &quot;foo&quot; with a term that you have in your glossary.
<h4>Term Replacement / Site Filtering</h4>
<p>If you turn on site filtering, every instance of each of your terms that shows up on the site will become a link. Depending on the mode you choose in the admin,
this will either be a link to your main Glossary page or open to the term in question.</p>
<p>Site filtering is an intensive process, and will slow your site down somewhat. There is an alternate, faster implementation that I may use to replace the existing one,
if there are enough complaints. It&#039;s more complicated, and I&#039;m lazy, but given sufficient demand, I&#039;ll fix it.</p>
<h3>Credits</h3>
<p>Development of this module has been generously sponsored by Matt Hornsby.</p>
<p>Extensive testing, QA, ideas, and non-negotiable demands provided by Paul &quot;InSiPiD&quot; Noone and Daniel &quot;Westis&quot; Westergren.</p>
<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report, please visit the
module homepage at <a href="http://dev.cmsmadesimple.org/projects/glossary/">the CMS Developer Forge</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
<li>The author, SjG, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
<li>Lastly, you may have some success emailing the author directly.</li>
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2006, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com">&amp;lt;sjg@cmsmodules.com&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
';
$lang['utma'] = '156861353.1652833779.1223550533.1223550533.1244630344.2';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1244630344.2.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>

==> Glossary-1.0.tar.gz: Glossary/lang/ext/nl_NL.php <==
<?php
$lang['info_filter_site'] = '<strong>Deprecated</strong> This functionality is deprecated, and will not be replaced.  It is recommended that you do not use this functionality';
$lang['areyousure_altercontent'] = 'Weet je zeker dat je door wil gaan? Doorgaan verandert de inhoud voorgoed';
$lang['filter_site_now'] = 'Filter nu';
$lang['friendlyname'] = 'Woordenlijst / Woordenboek';
$lang['postinstall'] = '<p>Vergewis u ervan de &quot;Modify Glossary&quot; rechten voor deze module in te stellen!</p>
<p>Waarschijnlijk wilt u de instellingen ook wijzigen. Er zijn opzettelijk vreemde standaardinstellingen gekozen om bepaalde mogelijkheden te tonen. Maar waarschijnlijk wilt u meer dan vijf termen per pagina, om een voorbeeld te noemen, en wilt u de voorbeeldtermen en -categorie&euml;n verwijderen.';
$lang['postuninstall'] = 'Verwijderd.';
$lang['uninstalled'] = 'Module gede&iuml;nstalleerd';
$lang['installed'] = 'Module versie %s ge&iuml;nstalleerd.';
$lang['prefsupdated'] = 'Modulevoorkeuren bijgewerkt.';
$lang['accessdenied'] = 'Toegang geweigerd. Controleer de rechten.';
$lang['error'] = 'Fout!';
$lang['upgraded'] = 'Module bijgewerkt naar versie %s.';
$lang['title_mod_prefs'] = 'Modulevoorkeuren';
$lang['title_mod_admin'] = 'Modulebeheerpagina';
$lang['title_term'] = 'Term ';
$lang['title_tip'] = 'Tool-tip / Link titel voor term';
$lang['title_definition'] = 'Definitie';
$lang['column_definition'] = 'Definitie';
$lang['title_default_template'] = 'Standaard weergavesjabloon';
$lang['title_default_single_term_template'] = 'Standaard sjabloon voor gekoppelde termen (als een enkele term wordt getoond)';
$lang['title_filter_site'] = 'Filter website op termen?';
$lang['title_filter_news'] = 'Filter News artikels voor termen?';
$lang['title_number_show'] = 'Aantal weer te geven termen per pagina';
$lang['title_default_number_show'] = 'Standaard aantal termen die worden getoond op de pagina';
$lang['title_filter_site_label'] = 'Activeer alle termen op de website? (waarschuwing - vertraagt de website)';
$lang['title_glossary_page'] = 'Woordenlijstpagina (target voor actieve links)';
$lang['title_disable_prettyurls'] = 'Schakel &quot;pretty urls&quot; uit voor deze module';
$lang['title_disable_prettyurls_label'] = 'Uitschakelen';
$lang['title_glossary_inline'] = 'Inline gekoppelde termweergave?';
$lang['title_show_termids'] = 'Toon Term ID nummers in administratie';
$lang['title_display_tab'] = 'Woordenlijst paginaweergaveopties';
$lang['title_single_term'] = 'Toon gekoppelde term op zijn eigen pagina?';
$lang['title_single_term_label'] = 'Toon enkele term (in tegenstelling tot volledige woordenlijst)';
$lang['title_wysiwyg_definitions'] = 'Gebruik WYSIWYG voor het invoeren van term definities?';
$lang['title_wysiwyg_terms'] = 'Gebruik WYSIWYG voor het invoeren van termen?';
$lang['title_wysiwyg_terms_help'] = 'Please note that markup inside terms can interfere with alphabetizing and with activated terms!';
$lang['title_link_tab'] = 'Woordenlijst koppelingsopties';
$lang['title_admin_tab'] = 'Beheerpagina opties';
$lang['title_filtering_tab'] = 'Website term/filteropties';
$lang['title_number_spining_chars'] = 'Maximaal aantal karakters in een term in de Woordenlijstnavigatie';
$lang['title_process_smarty'] = 'Gebruik Smarty tags in de definities?';
$lang['filter_link'] = 'Link naar Woordenlijstpagina';
$lang['column_term'] = 'Term ';
$lang['column_termid'] = 'Term-id';
$lang['column_action'] = 'Bewerking';
$lang['column_select'] = 'Selecteer';
$lang['column_category'] = 'Categorie';
$lang['title_admin_panel'] = 'Woordelijk / Woordenboek / FAQ';
$lang['title_term_list'] = 'Termen';
$lang['title_name'] = 'Naam';
$lang['title_cats'] = 'Categorie&euml;n';
$lang['title_filter_category'] = 'Toon alleen categorie:';
$lang['title_all'] = 'Alle categorie&euml;n';
$lang['column_template'] = 'Sjabloonnaam';
$lang['title_template'] = 'Sjabloondefinitie';
$lang['addterm'] = 'Voeg nieuwe term toe';
$lang['termadded'] = 'Term is toegevoegd.';
$lang['termdeleted'] = 'Term is verwijderd.';
$lang['edit'] = 'Bewerk term';
$lang['no'] = 'Nee';
$lang['yes'] = 'Ja';
$lang['filter'] = 'Filter ';
$lang['delete'] = 'Verwijder term';
$lang['delete_selected'] = 'Verwijder geselecteerde termen';
$lang['areyousure_deletemultiple'] = 'Weet u zeker dat u al deze termen wilt verwijderen?';
$lang['suredelete'] = 'Weet u zeker dat u term %s wilt verwijderen?';
$lang['listterms'] = 'Beheer termen';
$lang['listtempl'] = 'Beheer sjablonen';
$lang['listcats'] = 'Beheer categorie&euml;n';
$lang['addcat'] = 'Voeg categorie toe';
$lang['editcat'] = 'Bewerk categorie';
$lang['delcat'] = 'Verwijder categorie';
$lang['manageprefs'] = 'Beheervoorkeuren';
$lang['templatelist'] = 'Sjablonen';
$lang['unknown_term'] = 'Onbekende term %s is opgevraagd.';
$lang['glossary_page_help'] = 'Selecteer een onderstaande pagina die de tag bevat om de woordenlijstinformatie te tonen, b.v. een pagina met {cms_module module=&quot;Glossary&quot;}';
$lang['glossary_prettyurls_help'] = 'Uitschakelen van de &quot;pretty urls&quot; voor deze module kan helpen als niet-alfanumerieke waardes, of blancos worden gebruikt.';
$lang['glossary_inline_help'] = 'Gebruik de volgende optie als u uw actieve-termdefinities in-line wilt weergeven. Dit is wederzijds uitsluitend met een koppeling naar een Woordenlijstpagina';
$lang['title_glossary_inline_label'] = 'Toon inline';
$lang['notemplates'] = 'Geen sjablonen in de database.';
$lang['nocats'] = 'Geen categorie&euml;n in de database.';
$lang['addtemplate'] = 'Voeg een sjabloon toe';
$lang['templateupdated'] = 'Sjabloon bijgewerkt';
$lang['templatedeleted'] = 'Sjabloon verwijderd';
$lang['catupdated'] = 'Categorie bijgewerkt';
$lang['catdeleted'] = 'Categorie verwijderd';
$lang['areyousure'] = 'Weet u zeker dat %s verwijderd moet worden?';
$lang['next'] = ' : Volgende &raquo;';
$lang['prev'] = '&laquo; Vorige : ';
$lang['moddescription'] = 'Met deze module maakt u lijsten met termen en definities om weer te geven. Een term kan  een woord, een veelgestelde vraag of iets vergelijkbaars zijn.';
$lang['changelog'] = '';
$lang['help_glossary_single'] = 'Laat &eacute;&eacute;n term zien';
$lang['help_glossary_tid'] = 'Term ID om op te lichten';
$lang['help_glossary_catid'] = 'Restrict list to terms in category ID &quot;catid&quot;';
$lang['help_glossary_start'] = 'Offset in list to start listing terms';
$lang['help_glossary_term'] = 'Woord om op te lichten';
$lang['help_glossary_cat'] = 'Restrict list to terms in category &quot;cat&quot;';
$lang['help_glossary_template'] = 'Sjabloon naam of ID om te gebruiken bij Termen';
$lang['help_glossary_term_count'] = 'Aantal termen om te laten zien op een pagina (overschrijft standaard instellingen van de admin)';
$lang['help_glossary_show_nav'] = 'Stel in op 0 om de pagina navigatie te verstoppen';
$lang['help_glossary_keyword'] = 'Restrict to terms whose definitions contain &quot;keyword&quot;';
$lang['help_glossary_sort'] = 'Sort order: currently only supports &quot;alpha&quot; or &quot;random&quot;';
$lang['help_glossary_no_pass_restrictions'] = 'To display a filtered or otherwise restricted list, but to have the expanded list not restricted, list the fields here (see example above)';
$lang['help_glossary_target'] = 'Pagina alias om naar te verwijzen om alle termen op weer te geven';
$lang['utma'] = '156861353.679304078.1356693526.1356693526.1356769388.2';
$lang['utmz'] = '156861353.1356693526.1.1.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/files/6';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
